@@ -9,7 +9,7 @@ pub fn name(node: &Node) -> String {
 
 fn arglist(node: &Node, options: &Options) -> String {
     node.fields
-        .map(&|field| {
+        .map(|field| {
             format!(
                 "{field_type} {name}_blob",
                 field_type = fields::field_type(field, options),
